.. mitiq documentation master file, created by sphinx-quickstart

API-doc
=================================

.. automodule:: mitiq
   :members:

.. modules: alphabetical order

Benchmarks
----------

MaxCut
^^^^^^
.. automodule:: mitiq.benchmarks.maxcut
   :members:

Random Circuits
^^^^^^^^^^^^^^^
.. automodule:: mitiq.benchmarks.random_circuits
   :members:

Randomized Benchmarking
^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.benchmarks.randomized_benchmarking
   :members:

Utils
^^^^^
.. automodule:: mitiq.benchmarks.utils
   :members:

Clifford Data Regression
------------------------
.. automodule:: mitiq.cdr.clifford_training_data
   :members:

See Ref. :cite:`Czarnik_2020_arXiv` for more details on these methods.

Mitiq - Braket
--------------

Conversions
^^^^^^^^^^^
.. automodule:: mitiq.interface.mitiq_braket.conversions
   :members:

Mitiq - Cirq
------------

Cirq Utils
^^^^^^^^^^^
.. automodule:: mitiq.interface.mitiq_cirq.cirq_utils
   :members:

Mitiq - PyQuil
--------------

Conversions
^^^^^^^^^^^
.. automodule:: mitiq.interface.mitiq_pyquil.conversions
   :members:

Mitiq - Qiskit
--------------

Conversions
^^^^^^^^^^^
.. automodule:: mitiq.interface.mitiq_qiskit.conversions
   :members:

Qiskit Utils
^^^^^^^^^^^^
.. automodule:: mitiq.interface.mitiq_qiskit.qiskit_utils
   :members:

Probabilistic Error Cancellation
--------------------------------

Probabilistic Error Cancellation (High-Level Tools)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.pec.pec
   :members:

Quasi-Probability Representations
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.pec.representations.optimal
   :members:

.. automodule:: mitiq.pec.representations.damping
   :members:

.. automodule:: mitiq.pec.representations.depolarizing
   :members:

Sampling from a Noisy Decomposition of an Ideal Operation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.pec.sampling
   :members:

Probabilistic Error Cancellation Types
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.pec.types.types
   :members:

Utilities for Quantum Channels
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.pec.channels
   :members:


Zero Noise Extrapolation
------------------------

Zero Noise Extrapolation (High-Level Tools)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.zne.zne
   :members:

Inference and Extrapolation: Factories
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.zne.inference
   :members:

Noise Scaling: Unitary Folding
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.zne.scaling.folding
   :members:

Noise Scaling: Parameter Calibration
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mitiq.zne.scaling.parameter
   :members:
